import express from 'express';
import compression from 'compression';
import cors from 'cors';
import json from 'body-parser/lib/types/json.js';
import session from 'express-session';
import memorystore from 'memorystore';

import Log from './Log.js';
import EncriptorManager from './EncriptorManager.js';

export default class ExpressServer {

	static ENABLE_SESSION = false; // This can be override.
	static SESSION_DAYS = 30; // This can be override.

	static SESSION_AGE = this.SESSION_DAYS * 24 * 60 * 60 * 1_000;
	static DEV_URL = '//localhost';
	static PORT = 3000;

	static ENCRIPTOR;

	static init() {
		this.ENCRIPTOR = new EncriptorManager();
		this.router = express();

		this._neccesaryMiddlewares();
		this._beforeMiddlewares();
		this._initControllers();
		this._afterMiddlewares();

		this.router.listen(this.PORT, () => {
			Log.log(`Serving in ${this.URL()}`);
		});
	}

	static _neccesaryMiddlewares() {
		this._addSession();
		this.router.use(compression());
		this.router.use(cors());
		this.router.use(json(this._savingRawBody()));
	}

	static _addSession() {
		if (!this.ENABLE_SESSION) return;

		const FileStore = memorystore(session);
		this.router.use(session({
			secret: this.ENCRIPTOR._session._password,
			resave: true, saveUninitialized: true,
			cookie: { maxAge: this.SESSION_AG, sameSite: true },
			store: new FileStore({
				checkPeriod: 86400000
			})
		}));
	}

	static _savingRawBody() {
		return {
			verify: (req, res, buf) => {
				req.rawBody = buf;
			}
		};
	}

	static _beforeMiddlewares() {
		// Override by children.
	}

	static _initControllers() {
		// Override by children.
	}

	static _afterMiddlewares() {
		// Override by children.
	}

	static URL() {
		return `${this.DEV_URL}:${this.PORT}`;
	}

}
