import assert from 'assert';
import DateUtil from '../src/DateUtil.js';
import Message from '../src/Message.js';

describe('DateUtil.js', function () {

    describe('#getLocaleFromLanguageCode(languageCode)', function () {

        it('should return correctly the locale for the "es" value', function () {
            var languageCode = Message.SPANISH;

            var expected = 'es-ES';
            var result = DateUtil.getLocaleFromLanguageCode(languageCode);
            assert.deepStrictEqual(result, expected);
        });

        it('should return correctly the locale for the "en" value', function () {
            var languageCode = Message.ENGLISH;

            var expected = 'en-US';
            var result = DateUtil.getLocaleFromLanguageCode(languageCode);
            assert.deepStrictEqual(result, expected);
        });
    });

    describe('#toLocaleString(date, languageCode)', function () {

        it('should return correctly the locale date for the "es" value', function () {
            var languageCode = Message.SPANISH;
            var date = new Date(1653507590530)

            var expected = '25/5/2022, 19:39:50';
            var result = DateUtil.toLocaleString(date, languageCode);
            assert.deepStrictEqual(result, expected);
        });

        it('should return correctly the locale date for the "en" value', function () {
            var languageCode = Message.ENGLISH;
            var date = new Date(1653504490530)

            var expected = '5/25/2022, 6:48:10 PM';
            var result = DateUtil.toLocaleString(date, languageCode);
            assert.deepEqual(result, expected);
        });
    });

});
